@@ -80,6 +80,8 @@ enum MainOptions: Int, CaseIterable, SectionType {
         }
     }
 
+    var containsInfobutton: Bool { return false }
+
     var subtitle: String? {
         switch self {
         case .privacy:
@@ -150,6 +152,8 @@ enum GenericOptions: Int, CaseIterable, SectionType {
         }
     }
 
+    var containsInfobutton: Bool { return false }
+
     var subtitle: String? {
         switch self {
         case .defaultPlaybackSpeed:
@@ -230,6 +234,8 @@ enum PrivacyOptions: Int, CaseIterable, SectionType {
         }
     }
 
+    var containsInfobutton: Bool { return false }
+
     var subtitle: String? {
         switch self {
         case .passcodeLock:
@@ -273,9 +279,29 @@ enum PlaybackControlOptions: Int, CaseIterable, SectionType {
     case swipeUpDownForBrightness
     case swipeRightLeftToSeek
     case pinchToClose
-    case variableJumpDuration
+    case forwardSkipLength
+    case backwardSkipLength
 
-    var containsSwitch: Bool { return true }
+    var containsInfobutton: Bool { return false }
+
+    var containsSwitch: Bool {
+        switch self {
+        case .swipeUpDownForVolume:
+            return true
+        case .twoFingerTap:
+            return true
+        case .swipeUpDownForBrightness:
+            return true
+        case .swipeRightLeftToSeek:
+            return true
+        case .pinchToClose:
+            return true
+        case .forwardSkipLength:
+            return false
+        case .backwardSkipLength:
+            return false
+        }
+    }
 
     var description: String {
         switch self {
@@ -289,8 +315,10 @@ enum PlaybackControlOptions: Int, CaseIterable, SectionType {
             return "SETTINGS_GESTURES_SEEK"
         case .pinchToClose:
             return "SETTINGS_GESTURES_CLOSE"
-        case .variableJumpDuration:
-            return "SETTINGS_GESTURE_JUMP_DURATION"
+        case .forwardSkipLength:
+            return "SETTINGS_PLAYBACK_SKIP_FORWARD"
+        case .backwardSkipLength:
+            return "SETTINGS_PLAYBACK_SKIP_BACKWARD"
         }
     }
 
@@ -308,8 +336,10 @@ enum PlaybackControlOptions: Int, CaseIterable, SectionType {
             return kVLCSettingSeekGesture
         case .pinchToClose:
             return kVLCSettingCloseGesture
-        case .variableJumpDuration:
-            return kVLCSettingVariableJumpDuration
+        case .forwardSkipLength:
+            return kVLCSettingPlaybackForwardSkipLength
+        case .backwardSkipLength:
+            return kVLCSettingPlaybackBackwardSkipLength
         }
     }
 }
@@ -318,6 +348,7 @@ enum VideoOptions: Int, CaseIterable, SectionType {
     case deBlockingFilter
     case deInterlace
     case hardwareDecoding
+    case rememberPlayerBrightness
 
     var description: String {
         switch self {
@@ -327,10 +358,25 @@ enum VideoOptions: Int, CaseIterable, SectionType {
             return "SETTINGS_DEINTERLACE"
         case .hardwareDecoding:
             return "SETTINGS_HWDECODING"
+        case .rememberPlayerBrightness:
+            return "SETTINGS_REMEMBER_PLAYER_BRIGHTNESS"
         }
     }
 
-    var containsSwitch: Bool { return false }
+    var containsSwitch: Bool {
+        switch self {
+        case .deBlockingFilter:
+            return false
+        case .deInterlace:
+            return false
+        case .hardwareDecoding:
+            return false
+        case .rememberPlayerBrightness:
+            return true
+        }
+    }
+
+    var containsInfobutton: Bool { return true }
 
     var subtitle: String? {
         switch self {
@@ -340,6 +386,8 @@ enum VideoOptions: Int, CaseIterable, SectionType {
             return "SETTINGS_DEINTERLACE_OFF"
         case .hardwareDecoding:
             return "SETTINGS_HWDECODING_ON"
+        case .rememberPlayerBrightness:
+            return nil
         }
     }
 
@@ -351,6 +399,8 @@ enum VideoOptions: Int, CaseIterable, SectionType {
             return kVLCSettingDeinterlace
         case .hardwareDecoding:
             return kVLCSettingHardwareDecoding
+        case .rememberPlayerBrightness:
+            return kVLCPlayerShouldRememberBrightness
         }
     }
 }
@@ -421,6 +471,8 @@ enum SubtitlesOptions: Int, CaseIterable, SectionType {
             return kVLCSettingTextEncoding
         }
     }
+
+    var containsInfobutton: Bool { return false }
 }
 
 enum CastingOptions: Int, CaseIterable, SectionType {
@@ -462,6 +514,8 @@ enum CastingOptions: Int, CaseIterable, SectionType {
             return "SETTINGS_MEDIUM"
         }
     }
+
+    var containsInfobutton: Bool { return false }
 }
 
 enum AudioOptions: Int, CaseIterable, SectionType {
@@ -509,6 +563,8 @@ enum AudioOptions: Int, CaseIterable, SectionType {
             return kVLCSettingContinueAudioInBackgroundKey
         }
     }
+
+    var containsInfobutton: Bool { return false }
 }
 
 enum MediaLibraryOptions: Int, CaseIterable, SectionType {
@@ -563,6 +619,8 @@ enum MediaLibraryOptions: Int, CaseIterable, SectionType {
             return kVLCSettingBackupMediaLibrary
         }
     }
+
+    var containsInfobutton: Bool { return false }
 }
 
 enum NetworkOptions: Int, CaseIterable, SectionType {
@@ -622,6 +680,19 @@ enum NetworkOptions: Int, CaseIterable, SectionType {
             return kVLCSettingNetworkRTSPTCP
         }
     }
+
+    var containsInfobutton: Bool {
+        switch self {
+        case .networkCachingLevel:
+            return true
+        case .ipv6SupportForWiFiSharing:
+            return false
+        case .forceSMBv1:
+            return false
+        case .rtspctp:
+            return false
+        }
+    }
 }
 
 enum Lab: Int, CaseIterable, SectionType {
@@ -656,4 +727,6 @@ enum Lab: Int, CaseIterable, SectionType {
             return nil
         }
     }
+
+    var containsInfobutton: Bool { return false }
 }
